<?php
/**
 * BSeller - B2W Companhia Digital
 *
 * DISCLAIMER
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @copyright     Copyright (c) 2017 B2W Companhia Digital. (http://www.bseller.com.br/)
 * Access https://ajuda.skyhub.com.br/hc/pt-br/requests/new for questions and other requests.
 */

namespace B2W\SkyHub\Controller\Admin;

use B2W\SkyHub\Model\Map\MapAbstract;
use B2W\SkyHub\Model\Map\Order\AddressMap;
use B2W\SkyHub\Model\Map\CustomerMap;
use B2W\SkyHub\Model\Map\ProductMap;
use B2W\SkyHub\View\Admin\Admin;
use B2W\SkyHub\View\Admin\Attribute\EditAbstract;

/**
 * Class Attribute
 * @package B2W\SkyHub\Controller\Admin
 */
class Attribute extends AdminControllerAbstract
{
    /** @var MapAbstract */
    protected $_mapInstance     = null;
    /** @var EditAbstract */
    protected $_editInstance    = null;

    /**
     * @return $this
     * @throws \B2W\SkyHub\Exception\Helper\HelperNotFound
     */
    public function save()
    {
        if (!isset($_POST['entity_attribute']) || empty($_POST['entity_attribute'])) {
            return $this;
        }

        switch ($_POST['entity_attribute']) {
            case 'catalog/product' :
                $this->_mapInstance     = new ProductMap();
                $this->_editInstance    = new \B2W\SkyHub\View\Admin\Catalog\Product\Attribute\Edit();
                $redirect               = 'admin.php?page=' . Admin::SLUG_CATALOG_PRODUCT_ATTRIBUTE_LIST;
                break;

            case 'customer' :
                $this->_mapInstance     = new CustomerMap();
                $this->_editInstance    = new \B2W\SkyHub\View\Admin\Sales\Order\Customer\Edit();
                $redirect               = 'admin.php?page='. Admin::SLUG_SALES_ORDER_CUSTOMER_ATTRIBUTE_LIST;
                break;
            case 'sales/order/address' :
                $this->_mapInstance     = new AddressMap();
                $this->_editInstance    = new \B2W\SkyHub\View\Admin\Sales\Order\Address\Edit();
                $redirect               = 'admin.php?page='. Admin::SLUG_SALES_ORDER_ADDRESS_ATTRIBUTE_LIST;
        }

        if (!($this->validateNonce() && current_user_can( 'manage_options' ))) {
            $this->_redirect();
            exit;
        }

        $attr       = sanitize_text_field($_POST['attribute-code']);
        $related    = sanitize_text_field($_POST['related-attribute']);

        if ($this->_editInstance->validate($attr, $related)) {
            $this->_mapInstance->setRelated($attr, $related);
            $this->_mapInstance->save();
        }

        $this->_redirect($redirect);

        return $this;
    }
}
