<?php
/**
 * BSeller - B2W Companhia Digital
 *
 * DISCLAIMER
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @copyright     Copyright (c) 2019 B2W Companhia Digital. (http://www.bseller.com.br/)
 * Access https://ajuda.skyhub.com.br/hc/pt-br/requests/new for questions and other requests.
 */

namespace B2W\SkyHub\Model\Entity;

use B2W\SkyHub\Model\Entity\EntityAbstract;
use B2W\SkyHub\Model\Cron\Jobs;

/**
 * Class Attribute
 * @package B2W\SkyHub\Model\Map
 */
class SettingsApiEntity extends EntityAbstract
{
    /**
     * @var String
     */
    protected $email = '';

    /**
     * @var String
     */
    protected $apiKey = '';

    /**
     * @var String
     */
    protected $xAccountKey = '';

    /**
     * @var String
     */
    protected $orderIntegration = 'every_minute';

    /**
     * @var String
     */
    protected $orderIntegration_api = 'every_minute';

    /**
     * @var String
     */
    protected $productIntegration = 'every_minute';

    /**
     * @var String
     */
    protected $qtyStockDefault = '99';

    /**
     * @var String
     */
    protected $logFileName = 'skyhub_api.log';

    /**
     * @var String
     */
    protected $logFilePath = 'var/log/';

    /**
     * @var String
     */
    protected $logAllowed = false;

    /**
     * Get datas database
     *
     * @return SettingsApiEntity
     */
    public function map()
    {
        $datas = get_option($this->_getOptionsName(), null);
        if (!is_array($datas)) {
            return $this;
        }
        
        foreach ($datas as $key => $value) {
            $method = \App::helper('app')->getSetterMethodName($this, $key);

            if (!$method) {
                continue;
            }
            $this->$method($value);
        }
        return $this;
    }

    /**
     * Get the value of email
     *
     * @return  String
     */
    public function getEmail()
    {
        return $this->email;
    }

    /**
     * Set the value of email
     *
     * @param  String  $email
     *
     * @return  self
     */
    public function setEmail($email)
    {
        $this->email = $email;

        return $this;
    }

    /**
     * Get the value of apiKey
     *
     * @return  String
     */
    public function getApiKey()
    {
        return $this->apiKey;
    }

    /**
     * Set the value of apiKey
     *
     * @param  String  $apiKey
     *
     * @return  self
     */
    public function setApiKey($apiKey)
    {
        $this->apiKey = $apiKey;

        return $this;
    }

    /**
     * Get the value of xAccountKey
     *
     * @return  String
     */
    public function getXAccountKey()
    {
        return $this->xAccountKey;
    }

    /**
     * Set the value of xAccountKey
     *
     * @param  String  $xAccountKey
     *
     * @return  self
     */
    public function setXAccountKey($xAccountKey)
    {
        $this->xAccountKey = $xAccountKey;

        return $this;
    }

    protected function _getOptionsName()
    {
        return 'b2w_skyhub_settings_api';
    }

    /**
     * Save datas settingsAPI
     */
    public function save()
    {
        update_option($this->_getOptionsName(), $this->toArray());
        $jobs = new Jobs();
        $jobs->registerCronJobs(true);
    }

    /**
     * Get the value of orderIntegration
     *
     * @return  String
     */
    public function getOrderIntegration()
    {
        return $this->orderIntegration;
    }

    /**
     * Set the value of orderIntegration
     *
     * @param  String  $orderIntegration
     *
     * @return  self
     */
    public function setOrderIntegration($orderIntegration)
    {
        $this->orderIntegration = $orderIntegration;

        return $this;
    }

    /**
     * Get the value of orderIntegration_api
     *
     * @return  String
     */
    public function getOrderIntegrationApi()
    {
        return $this->orderIntegration_api;
    }

    /**
     * Set the value of orderIntegration_api
     *
     * @param  String  $orderIntegration_api
     *
     * @return  self
     */
    public function setOrderIntegrationApi($orderIntegration_api)
    {
        $this->orderIntegration_api = $orderIntegration_api;

        return $this;
    }

    /**
     * Get the value of productInegration
     *
     * @return  String
     */
    public function getProductIntegration()
    {
        return $this->productIntegration;
    }

    /**
     * Set the value of productInegration
     *
     * @param  String  $productInegration
     *
     * @return  self
     */
    public function setProductIntegration($productIntegration)
    {
        $this->productIntegration = $productIntegration;

        return $this;
    }

    /**
     * Get the value of qtyStockDefault
     *
     * @return  String
     */
    public function getQtyStockDefault()
    {
        return $this->qtyStockDefault;
    }

    /**
     * Set the value of qtyStockDefault
     *
     * @param  String  $qtyStockDefault
     *
     * @return  self
     */
    public function setQtyStockDefault($qtyStockDefault)
    {
        $this->qtyStockDefault = $qtyStockDefault;

        return $this;
    }

    /**
     * Get the value of logFileName
     *
     * @return  String
     */
    public function getLogFileName()
    {
        return $this->logFileName;
    }

    /**
     * Set the value of logFileName
     *
     * @param  String  $logFileName
     *
     * @return  self
     */
    public function setLogFileName($logFileName)
    {
        $this->logFileName = $logFileName;

        return $this;
    }

    /**
     * Get the value of logFilePath
     *
     * @return  String
     */
    public function getLogFilePath()
    {
        return $this->logFilePath;
    }

    /**
     * Set the value of logFilePath
     *
     * @param  String  $logFilePath
     *
     * @return  self
     */
    public function setLogFilePath($logFilePath)
    {
        if (substr($logFilePath, 0, 1) == '/') {
            $logFilePath = substr($logFilePath, 1);
        }
        $this->logFilePath = $logFilePath;

        return $this;
    }

    /**
     * Get the value of logAllowed
     *
     * @return  String
     */
    public function getLogAllowed()
    {
        return $this->logAllowed;
    }

    /**
     * Set the value of logAllowed
     *
     * @param  String  $logAllowed
     *
     * @return  self
     */
    public function setLogAllowed($logAllowed)
    {
        $this->logAllowed = (bool)$logAllowed;

        return $this;
    }
}
