<?php
/**
 * BSeller - B2W Companhia Digital
 *
 * DISCLAIMER
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @copyright     Copyright (c) 2017 B2W Companhia Digital. (http://www.bseller.com.br/)
 * Access https://ajuda.skyhub.com.br/hc/pt-br/requests/new for questions and other requests.
 */

namespace B2W\SkyHub\Model\Map\Order;

use B2W\SkyHub\Model\Map\MapAbstract;
use B2W\SkyHub\Model\Map\MapAttribute;
use B2W\SkyHub\Model\Resource\Collection;
use SkyHub\Api\Handler\Response\HandlerDefault;

/**
 * Class StatusMap
 * @package B2W\SkyHub\Model\Map\Sales\Order\Status
 */
class StatusMap extends MapAbstract
{
    /**
     * @return string
     */
    protected function _getConfigPath()
    {
        return 'map/order/status';
    }

    /**
     * @return string
     */
    protected function _getOptionsName()
    {
        return 'b2w_skyhub_sales_order_status';
    }

    /**
     * @return Collection
     * @throws \B2W\SkyHub\Exception\Data\RepositoryNotFound
     * @throws \B2W\SkyHub\Exception\Helper\HelperNotFound
     */
    protected function _loadMap()
    {
        /** @var HandlerDefault $statuses */
        $statuses   = \App::apiRepository(\App::REPOSITORY_ORDER_STATUS)->all();
        $collection = new Collection();

        //load from API
        foreach ($statuses->toArray() as $status) {
            $map = new MapAttribute();

            $map->setSkyhub(strtolower($status['type']));
            $map->setWordpress(null);
            $map->setMapper(null);
            $map->setLabel($status['label']);

            $collection->addItem($map);
        }

        //set default wordpress config
        foreach (\App::config($this->_getConfigPath()) as $config) {
            $item = $collection->getItemByKey('_skyhub', $config['skyhub']);

            if ($item && isset($config['wordpress']) && !empty($config['wordpress'])) {
                $item->setWordpress($config['wordpress']);
            }
        }

        return $collection;
    }
}
