<?php
/**
 * BSeller - B2W Companhia Digital
 *
 * DISCLAIMER
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @copyright     Copyright (c) 2019 B2W Companhia Digital. (http://www.bseller.com.br/)
 * Access https://ajuda.skyhub.com.br/hc/pt-br/requests/new for questions and other requests.
 */

namespace B2W\SkyHub\Model\Queue\Worker;

use B2W\SkyHub\Exception\Integrator\Catalog\Product\Validation\ProductNotExistException;

/**
 * Class ProductUpdateWorker
 * @package B2W\SkyHub\Model\Queue\Worker
 */
class ProductUpdateWorker
{
    /**
     * @param $productId
     * @return $this
     * @throws \B2W\SkyHub\Exception\Data\RepositoryNotFound
     */
    public function run($productId)
    {
        $product    = $this->_getProduct($productId);
        if (!$product) {
            throw new ProductNotExistException("Product not exist in your system - ID: $productId");
        }

        $response = \App::apiRepository(\App::REPOSITORY_PRODUCT_API)->save($product);
        if ($response->success()) {
            $skyhub_product_integrated = get_metadata('post', $productId, '_skyhub_product_integrated');

            if (!$skyhub_product_integrated) {
                add_metadata('post', $productId, '_skyhub_product_integrated', 'true');
            }
        }
        return $response;
    }

    /**
     * @param $productId
     * @return mixed
     * @throws \B2W\SkyHub\Exception\Data\RepositoryNotFound
     */
    protected function _getProduct($productId)
    {
        return \App::repository(\App::REPOSITORY_PRODUCT)->one($productId);
    }
}
