<?php
/**
 * BSeller - B2W Companhia Digital
 *
 * DISCLAIMER
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @copyright     Copyright (c) 2017 B2W Companhia Digital. (http://www.bseller.com.br/)
 * Access https://ajuda.skyhub.com.br/hc/pt-br/requests/new for questions and other requests.
 */

namespace B2W\SkyHub\Model\Repository;

use B2W\SkyHub\Contract\Repository\CustomerRepositoryInterface;
use B2W\SkyHub\Model\Entity\CustomerEntity;
use B2W\SkyHub\Model\Resource\Select;
use B2W\SkyHub\Model\Transformer\Customer\DbToEntity;

/**
 * Class CustomerDbRepository
 * @package B2W\SkyHub\Model\Repository
 */
class CustomerDbRepository implements CustomerRepositoryInterface
{
    /**
     * @param \B2W\SkyHub\Contract\Entity\OrderEntityInterface|\WP_Post $order
     * @return \B2W\SkyHub\Model\Entity\CustomerEntity
     * @throws \Exception
     */
    public function load($order)
    {
        $post           = $order instanceof \WP_Post ? $order : get_post($order->getId());
        $customer       = new CustomerEntity();
        $transformer    = new DbToEntity();
        $transformer->convert($post, $customer);

        return $customer;
    }

    /**
     * @param $cpf
     * @return \B2W\SkyHub\Contract\Entity\CustomerEntityInterface|CustomerEntity|null
     * @throws \B2W\SkyHub\Exception\Data\TransformerNotFound
     */
    public function cpf($cpf)
    {
        global $wpdb;

        $cpf = preg_replace('/[^0-9]+/', '', $cpf);

        $select = new Select();
        $select->column('user_id');
        $select->from('usermeta');
        $select->where("meta_key = 'billing_cpf'");
        $select->where("REPLACE(REPLACE(meta_value, '.', ''), '-', '') = '$cpf'");

        foreach ($wpdb->get_results($select) as $customer) {
            return $this->one($customer->user_id);
        }

        return new CustomerEntity();
    }

    /**
     * @param $cnpj
     * @return \B2W\SkyHub\Contract\Entity\CustomerEntityInterface|CustomerEntity|null
     * @throws \B2W\SkyHub\Exception\Data\TransformerNotFound
     */
    public function cnpj($cnpj)
    {
        global $wpdb;

        $cnpj = preg_replace('/[^0-9]+/', '', $cnpj);

        $select = new Select();
        $select->column('user_id');
        $select->from('usermeta');
        $select->where("meta_key = 'billing_cnpj'");
        $select->where("REPLACE(REPLACE(meta_value, '.', ''), '-', '') = '$cnpj'");

        foreach ($wpdb->get_results($select) as $customer) {
            return $this->one($customer->user_id);
        }

        return new CustomerEntity();
    }

    /**
     * @param $id
     * @return \B2W\SkyHub\Contract\Entity\CustomerEntityInterface|null
     * @throws \B2W\SkyHub\Exception\Data\TransformerNotFound
     * @throws \Exception
     */
    public function one($id)
    {
        $user       = get_user_by('id', $id);
        $meta       = get_user_meta($id);

        /** @var DbToEntity $transformer */
        $transformer = new DbToEntity();
        $transformer->setPost($user);
        $transformer->setMeta($meta);

        return $transformer->convert();
    }
}
