<?php
/**
 * BSeller - B2W Companhia Digital
 *
 * DISCLAIMER
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @copyright     Copyright (c) 2017 B2W Companhia Digital. (http://www.bseller.com.br/)
 * Access https://ajuda.skyhub.com.br/hc/pt-br/requests/new for questions and other requests.
 */

namespace B2W\SkyHub\Model\Repository\Product;

use B2W\SkyHub\Contract\Entity\Product\VariationEntityInterface;
use B2W\SkyHub\Contract\Repository\Product\VariationRepositoryInterface;
use B2W\SkyHub\Model\Resource\Collection;
use B2W\SkyHub\Model\Resource\Select;
use B2W\SkyHub\Model\Transformer\Product\Variation\DbToEntity;

class VariationDbRepository implements VariationRepositoryInterface
{
    /**
     * Verify if product is simple
     *
     * @param int $idProduct
     * @return bool
     */
    public function verifyProductVariation($idProduct)
    {
        global $wpdb;

        $select = new Select();

        $select->column([
            'terms.term_id',
            'terms.name'
        ]);

        $select->from('term_relationships', 'main_table');

        $select->join(
            'term_taxonomy',
            "main_table.term_taxonomy_id = term_taxonomy.term_taxonomy_id",
            'term_taxonomy'
        );

        $select->join(
            'terms',
            "terms.term_id = term_taxonomy.term_id",
            'terms'
        );

        $select->where("main_table.object_id = '$idProduct'");
        $select->where("term_taxonomy.taxonomy = 'product_type'");
        $query = $select->prepare();
        $results    = $wpdb->get_results($query);

        foreach ($results as $result) {
            if ($result->name == 'simple') {
                return false;
            }
        }
        return true;
    }

    /**
     * @param \B2W\SkyHub\Contract\Entity\ProductEntityInterface|\WP_Post $product
     * @return Collection
     * @throws \Exception
     */
    public function load($product)
    {
        $filter = array(
            'post_status'   => array('publish'),
            'numberposts'   => null,
            'nopaging'      => true,
            'post_type'     => VariationEntityInterface::POST_TYPE,
            'post_parent'   => $product instanceof \B2W\SkyHub\Contract\Entity\ProductEntityInterface
                ? $product->getId()
                : $product->ID
        );

        $collection = new Collection();
        if (!$this->verifyProductVariation($filter['post_parent'])) {
            return $collection;
        }

        $posts      = get_posts($filter);

        foreach ($posts as $post) {
            $variation = $this->one($post);
            $collection->addItem($variation);
        }

        return $collection;
    }

    /**
     * @param $id
     * @return mixed|null
     * @throws \Exception
     */
    public function one($id)
    {
        if ($id instanceof \WP_Post) {
            $post = $id;
        } else {
            $post = get_post($id);
        }

        /** @var \B2W\SkyHub\Model\Transformer\Product\Variation\DbToEntity $transformer */
        $transformer = new DbToEntity();
        $transformer->setPost($post);
        $transformer->setMeta(get_post_meta($post->ID));
        return $transformer->convert();
    }

    /**
     * @param $sku
     * @return bool|mixed|null
     * @throws \Exception
     */
    public function sku($sku)
    {
        global $wpdb;

        $sku = sanitize_text_field($sku);

        $select = new Select();
        $select->column('post_id');
        $select->from('postmeta');
        $select->where("meta_key = '_sku'");
        $select->where("meta_value= '$sku'");

        foreach ($wpdb->get_results($select) as $row) {
            return $this->one($row->post_id);
        }

        return false;
    }
}
