<?php
/**
 * BSeller - B2W Companhia Digital
 *
 * DISCLAIMER
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @copyright     Copyright (c) 2017 B2W Companhia Digital. (http://www.bseller.com.br/)
 * Access https://ajuda.skyhub.com.br/hc/pt-br/requests/new for questions and other requests.
 */

namespace B2W\SkyHub\View\Admin;


use B2W\SkyHub\Contract\Entity\OrderEntityInterface;
use B2W\SkyHub\View\Template;
use B2W\SkyHub\Model\Entity\Order\Shipment\TrackEntity;

/**
 * Class Order
 * @package B2W\SkyHub\View\Admin
 */
class Order extends Template
{
    /** @var OrderEntityInterface */
    protected $_order    = null;

    /**
     * SkyHub details to API
     */
    public function init()
    {
        if (!$this->getOrder()->getChannel()) {
            return;
        }

        $this->addInvoiceKey();
        $this->addTrack();
        $this->addInvoiceXml();
    }

    /**
     * Add invoice key in order details
     *
     * @return bool
     */
    protected function addInvoiceKey()
    {
        $order = $this->getOrder();
        if ($order->getCalculationType() == 'b2wentregadirect') {
            return false;
        }

        if ($order->getStatus()->getType() == 'NEW') {
            return false;
        }

        $this->setTemplate('admin/order/details.php');
        add_meta_box(
            'woocommerce-b2w-order',
            _('Skyhub Order Details'),
            array($this, 'render'),
            OrderEntityInterface::POST_TYPE
        );
        return true;
    }

    /**
     * Add track in order details
     *
     * @return bool
     */
    protected function addTrack()
    {
        $order = $this->getOrder();
        $invoice = $order->getInvoices()->first();
        $key = ($invoice ? $invoice->getKey() : null);
        if (!$key) {
            return false;
        }

        if ($order->getStatus()->getType() == 'NEW') {
            return false;
        }

        $track = clone $this;
        $track->setTemplate('admin/order/details_track.php');
        add_meta_box(
            'woocommerce-b2w-order_shipping',
            _('Skyhub Order Shipping Details'),
            array($track, 'render'),
            OrderEntityInterface::POST_TYPE
        );
        return true;
    }

    /**
     * Add invoice xml in order details
     *
     * @return bool
     */
    protected function addInvoiceXml()
    {
        delete_option(\B2W\SkyHub\Controller\Order::SENTINVOICEXMLSKYHUB);
        $order = $this->getOrder();
        if ($order->getStatus()->getType() !== 'APPROVED') {
            return false;
        }

        if ($order->getCalculationType() !== 'b2wentregadirect') {
            return false;
        }

        $invoice = clone $this;
        $invoice->setTemplate('admin/order/invoice-xml.php');
        add_meta_box(
            'woocommerce-b2w-order_invoice',
            _('SkyHub Order Xml Nfe'),
            array($invoice, 'render'),
            OrderEntityInterface::POST_TYPE
        );
        return true;
    }

    public function isEditable()
    {
        if ($this->getOrder()->getStatus()->getCode() == 'wc-cancelled') {
            return false;
        }
        return true;
    }

    /**
     * @return OrderEntityInterface
     * @throws \B2W\SkyHub\Exception\Data\RepositoryNotFound
     */
    public function getOrder()
    {
        if (is_null($this->_order)) {
            $postId = $_GET['post'];
            $this->_order = \App::repository(\App::REPOSITORY_ORDER)->one($postId);
        }

        return $this->_order;
    }
}
